You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/12/01 08:27:13 UTC

svn commit: r1208981 [14/24] - in /struts/struts2/branches/STRUTS_3_X: apps/blank/src/main/java/example/ apps/blank/src/test/java/example/ apps/jboss-blank/src/main/java/example/ apps/jboss-blank/src/test/java/example/ apps/mailreader/src/main/java/mai...

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationUtils.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationUtils.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationUtils.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationUtils.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.location;
+package org.apache.struts2.xwork2.util.location;
 
-import com.opensymphony.xwork2.util.ClassLoaderUtil;
+import org.apache.struts2.xwork2.util.ClassLoaderUtil;
 import org.w3c.dom.Element;
 import org.xml.sax.Locator;
 import org.xml.sax.SAXParseException;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/Logger.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/Logger.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/Logger.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/Logger.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.logging;
+package org.apache.struts2.xwork2.util.logging;
 
 /**
  * Main logger interface for logging things

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerFactory.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.logging;
+package org.apache.struts2.xwork2.util.logging;
 
-import com.opensymphony.xwork2.util.logging.jdk.JdkLoggerFactory;
+import org.apache.struts2.xwork2.util.logging.jdk.JdkLoggerFactory;
 
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
@@ -60,7 +60,7 @@ public abstract class LoggerFactory {
             if (factory == null) {
                 try {
                     Class.forName("org.apache.commons.logging.LogFactory");
-                    factory = new com.opensymphony.xwork2.util.logging.commons.CommonsLoggerFactory();
+                    factory = new org.apache.struts2.xwork2.util.logging.commons.CommonsLoggerFactory();
                 } catch (ClassNotFoundException ex) {
                     // commons logging not found, falling back to jdk logging
                     factory = new JdkLoggerFactory();

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerUtils.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerUtils.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerUtils.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerUtils.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.logging;
+package org.apache.struts2.xwork2.util.logging;
 
 /**
  * Logging utility methods

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/commons/CommonsLogger.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/commons/CommonsLogger.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/commons/CommonsLogger.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/commons/CommonsLogger.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.logging.commons;
+package org.apache.struts2.xwork2.util.logging.commons;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerUtils;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerUtils;
 import org.apache.commons.logging.Log;
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/commons/CommonsLoggerFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/commons/CommonsLoggerFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/commons/CommonsLoggerFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/commons/CommonsLoggerFactory.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.logging.commons;
+package org.apache.struts2.xwork2.util.logging.commons;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.logging.LogFactory;
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/jdk/JdkLogger.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/jdk/JdkLogger.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/jdk/JdkLogger.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/jdk/JdkLogger.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.logging.jdk;
+package org.apache.struts2.xwork2.util.logging.jdk;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerUtils;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerUtils;
 
 import java.util.logging.Level;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/jdk/JdkLoggerFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/jdk/JdkLoggerFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/jdk/JdkLoggerFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/jdk/JdkLoggerFactory.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.logging.jdk;
+package org.apache.struts2.xwork2.util.logging.jdk;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Creates jdk loggers

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/ObjectProfiler.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/ObjectProfiler.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/ObjectProfiler.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/ObjectProfiler.java Thu Dec  1 07:18:07 2011
@@ -24,7 +24,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-package com.opensymphony.xwork2.util.profiling;
+package org.apache.struts2.xwork2.util.profiling;
 
 import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.InvocationTargetException;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/ProfilingTimerBean.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/ProfilingTimerBean.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/ProfilingTimerBean.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/ProfilingTimerBean.java Thu Dec  1 07:18:07 2011
@@ -24,7 +24,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-package com.opensymphony.xwork2.util.profiling;
+package org.apache.struts2.xwork2.util.profiling;
 
 import java.util.ArrayList;
 import java.util.List;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/UtilTimerStack.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/UtilTimerStack.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/UtilTimerStack.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/profiling/UtilTimerStack.java Thu Dec  1 07:18:07 2011
@@ -24,10 +24,10 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-package com.opensymphony.xwork2.util.profiling;
+package org.apache.struts2.xwork2.util.profiling;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionContextFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionContextFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionContextFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionContextFactory.java Thu Dec  1 07:18:07 2011
@@ -1,4 +1,4 @@
-package com.opensymphony.xwork2.util.reflection;
+package org.apache.struts2.xwork2.util.reflection;
 
 import java.util.Map;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionContextState.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionContextState.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionContextState.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionContextState.java Thu Dec  1 07:18:07 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.util.reflection;
+package org.apache.struts2.xwork2.util.reflection;
 
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionException.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionException.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionException.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionException.java Thu Dec  1 07:18:07 2011
@@ -1,6 +1,6 @@
-package com.opensymphony.xwork2.util.reflection;
+package org.apache.struts2.xwork2.util.reflection;
 
-import com.opensymphony.xwork2.XWorkException;
+import org.apache.struts2.xwork2.XWorkException;
 
 public class ReflectionException extends XWorkException {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionExceptionHandler.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionExceptionHandler.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionExceptionHandler.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionExceptionHandler.java Thu Dec  1 07:18:07 2011
@@ -1,4 +1,4 @@
-package com.opensymphony.xwork2.util.reflection;
+package org.apache.struts2.xwork2.util.reflection;
 
 /**
  * Declares a class that wants to handle its own reflection exceptions

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionProvider.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionProviderFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionProviderFactory.java Thu Dec  1 07:18:07 2011
@@ -1,6 +1,6 @@
-package com.opensymphony.xwork2.util.reflection;
+package org.apache.struts2.xwork2.util.reflection;
 
-import com.opensymphony.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionContext;
 
 public class ReflectionProviderFactory {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultActionValidatorManager.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultActionValidatorManager.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultValidatorFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultValidatorFactory.java Thu Dec  1 07:18:07 2011
@@ -13,15 +13,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.XWorkException;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ClassLoaderUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.XWorkException;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ClassLoaderUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.io.File;
 import java.io.FilenameFilter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultValidatorFileParser.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultValidatorFileParser.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultValidatorFileParser.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultValidatorFileParser.java Thu Dec  1 07:18:07 2011
@@ -13,15 +13,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.providers.XmlHelper;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.DomHelper;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.providers.XmlHelper;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.DomHelper;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.w3c.dom.*;
 import org.xml.sax.InputSource;
 
@@ -40,7 +40,7 @@ import java.util.*;
  * @author Rene Gielen
  * @author Martin Gilday
  * 
- * @see com.opensymphony.xwork2.validator.ValidatorConfig
+ * @see org.apache.struts2.xwork2.validator.ValidatorConfig
  */
 public class DefaultValidatorFileParser implements ValidatorFileParser {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DelegatingValidatorContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DelegatingValidatorContext.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DelegatingValidatorContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DelegatingValidatorContext.java Thu Dec  1 07:18:07 2011
@@ -13,12 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
-import com.opensymphony.xwork2.*;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.*;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.*;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/FieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/FieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/FieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/FieldValidator.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
 /**
  * The FieldValidator interface defines the methods to be implemented by FieldValidators.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ShortCircuitableValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ShortCircuitableValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ShortCircuitableValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ShortCircuitableValidator.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidationException.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidationException.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidationException.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidationException.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidationInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidationInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/Validator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/Validator.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorConfig.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorConfig.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorConfig.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorConfig.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
-import com.opensymphony.xwork2.util.location.Located;
-import com.opensymphony.xwork2.util.location.Location;
+import org.apache.struts2.xwork2.util.location.Located;
+import org.apache.struts2.xwork2.util.location.Location;
 
 import java.util.Collections;
 import java.util.LinkedHashMap;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorContext.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorContext.java Thu Dec  1 07:18:07 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
-import com.opensymphony.xwork2.LocaleProvider;
-import com.opensymphony.xwork2.TextProvider;
-import com.opensymphony.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.LocaleProvider;
+import org.apache.struts2.xwork2.TextProvider;
+import org.apache.struts2.xwork2.ValidationAware;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorFactory.java Thu Dec  1 07:18:07 2011
@@ -1,4 +1,4 @@
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
 /**
  * ValidatorFactory

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorFileParser.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorFileParser.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorFileParser.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidatorFileParser.java Thu Dec  1 07:18:07 2011
@@ -1,4 +1,4 @@
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
 import java.io.InputStream;
 import java.util.List;
@@ -23,7 +23,7 @@ import java.util.Map;
  * @author Rob Harrop
  * @author Rene Gielen
  *
- * @see com.opensymphony.xwork2.validator.ValidatorConfig
+ * @see org.apache.struts2.xwork2.validator.ValidatorConfig
  */
 public interface ValidatorFileParser {
     /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ConditionalVisitorFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ConditionalVisitorFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ConditionalVisitorFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ConditionalVisitorFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -1,4 +1,4 @@
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ConversionErrorFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ConversionErrorFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ConversionErrorFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ConversionErrorFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/CustomValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/CustomValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/CustomValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/CustomValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/DateRangeFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/DateRangeFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/DateRangeFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/DateRangeFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/DoubleRangeFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/DoubleRangeFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/DoubleRangeFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/DoubleRangeFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/EmailValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/EmailValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/EmailValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/EmailValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ExpressionValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ExpressionValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ExpressionValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ExpressionValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/FieldExpressionValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/FieldExpressionValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/FieldExpressionValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/FieldExpressionValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/IntRangeFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/IntRangeFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/IntRangeFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/IntRangeFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RegexFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RegexFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RegexFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RegexFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RequiredFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RequiredFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RequiredFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RequiredFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RequiredStringValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RequiredStringValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RequiredStringValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/RequiredStringValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/StringLengthFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/StringLengthFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/StringLengthFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/StringLengthFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/UrlValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/UrlValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/UrlValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/UrlValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/Validation.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/Validation.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/Validation.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/Validation.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ValidationParameter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ValidationParameter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ValidationParameter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ValidationParameter.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/Validations.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/Validations.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/Validations.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/Validations.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ValidatorType.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ValidatorType.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ValidatorType.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/ValidatorType.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 /**
  * <code>ValidatorType</code>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/VisitorFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/VisitorFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/VisitorFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/annotations/VisitorFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.annotations;
+package org.apache.struts2.xwork2.validator.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ConversionErrorFieldValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ConversionErrorFieldValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ConversionErrorFieldValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ConversionErrorFieldValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/DateRangeFieldValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/DateRangeFieldValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/DateRangeFieldValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/DateRangeFieldValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/DoubleRangeFieldValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/DoubleRangeFieldValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/DoubleRangeFieldValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/DoubleRangeFieldValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/EmailValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/EmailValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/EmailValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/EmailValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ExpressionValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ExpressionValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ExpressionValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ExpressionValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/FieldExpressionValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/FieldExpressionValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/FieldExpressionValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/FieldExpressionValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/IntRangeFieldValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/IntRangeFieldValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/IntRangeFieldValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/IntRangeFieldValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/RequiredFieldValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/RequiredFieldValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/RequiredFieldValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/RequiredFieldValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/RequiredStringValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/RequiredStringValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/RequiredStringValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/RequiredStringValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/StringLengthFieldValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/StringLengthFieldValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/StringLengthFieldValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/StringLengthFieldValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/URLValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/URLValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/URLValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/URLValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/ValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 /**
  * <code>ValidatorDescription</code>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/VisitorFieldValidatorDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/VisitorFieldValidatorDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/VisitorFieldValidatorDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/metadata/VisitorFieldValidatorDescription.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.metadata;
+package org.apache.struts2.xwork2.validator.metadata;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ConditionalVisitorFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ConditionalVisitorFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ConditionalVisitorFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ConditionalVisitorFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -1,6 +1,6 @@
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 /**
  * <code>ConditionalVisitorFieldValidator</code>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ConversionErrorFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ConversionErrorFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ConversionErrorFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ConversionErrorFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 import java.util.Map;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/DateRangeFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/DateRangeFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/DateRangeFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/DateRangeFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
 import java.util.Date;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/DoubleRangeFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/DoubleRangeFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/DoubleRangeFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/DoubleRangeFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/EmailValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/EmailValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/EmailValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/EmailValidator.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ExpressionValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ExpressionValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ExpressionValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ExpressionValidator.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/FieldExpressionValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/FieldExpressionValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/FieldExpressionValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/FieldExpressionValidator.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/FieldValidatorSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/FieldValidatorSupport.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/FieldValidatorSupport.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/FieldValidatorSupport.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.FieldValidator;
+import org.apache.struts2.xwork2.validator.FieldValidator;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/IntRangeFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/IntRangeFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/IntRangeFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/IntRangeFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/LongRangeFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/LongRangeFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/LongRangeFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/LongRangeFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RegexFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RegexFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RegexFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RegexFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RepopulateConversionErrorFieldValidatorSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RepopulateConversionErrorFieldValidatorSupport.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RepopulateConversionErrorFieldValidatorSupport.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RepopulateConversionErrorFieldValidatorSupport.java Thu Dec  1 07:18:07 2011
@@ -13,15 +13,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.PreResultListener;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.PreResultListener;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.validator.ValidationException;
 import org.apache.commons.lang.StringEscapeUtils;
 
 import java.util.LinkedHashMap;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RequiredFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RequiredFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RequiredFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RequiredFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RequiredStringValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RequiredStringValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RequiredStringValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/RequiredStringValidator.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ShortRangeFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ShortRangeFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ShortRangeFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/ShortRangeFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/StringLengthFieldValidator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/StringLengthFieldValidator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/StringLengthFieldValidator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/validators/StringLengthFieldValidator.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator.validators;
+package org.apache.struts2.xwork2.validator.validators;
 
-import com.opensymphony.xwork2.validator.ValidationException;
+import org.apache.struts2.xwork2.validator.ValidationException;
 
 /**
  * <!-- START SNIPPET: javadoc -->
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionProvider.java Thu Dec  1 07:18:07 2011
@@ -1,4 +1,4 @@
-package com.opensymphony.xwork2.util.reflection;
+package org.apache.struts2.xwork2.util.reflection;
 
 import java.beans.IntrospectionException;
 import java.beans.PropertyDescriptor;
@@ -53,7 +53,7 @@ public interface ReflectionProvider {
 
     /**
      * Copies the properties in the object "from" and sets them in the object "to"
      * using specified type converter, or {@link com.opensymphony.xwork2.conversion.impl.XWorkConverter} if none
      * is specified.
      *
      * @param from       the source object
@@ -53,7 +53,7 @@ public interface ReflectionProvider {
     /**
      * Copies the properties in the object "from" and sets them in the object "to"
-     * using specified type converter, or {@link com.opensymphony.xwork2.conversion.impl.XWorkConverter} if none
+     * using specified type converter, or {@link org.apache.struts2.xwork2.conversion.impl.XWorkConverter} if none
      * is specified.
      *

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionProviderFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/reflection/ReflectionProviderFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultActionValidatorManager.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultActionValidatorManager.java Thu Dec  1 07:18:07 2011
@@ -13,15 +13,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.FileManager;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.validator.validators.VisitorFieldValidator;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.FileManager;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.validator.validators.VisitorFieldValidator;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -347,10 +347,10 @@ public class DefaultActionValidatorManag
 
 
     /**
      * An {@link com.opensymphony.xwork2.validator.ValidatorContext} wrapper that
      * returns the full field name
      * {@link InternalValidatorContextWrapper#getFullFieldName(String)}
      * by consulting it's parent if its an {@link com.opensymphony.xwork2.validator.validators.VisitorFieldValidator.AppendingValidatorContext}.
      * <p/>
      * Eg. if we have nested Visitor
      * AddressVisitor nested inside PersonVisitor, when using the normal #getFullFieldName, we will get
@@ -347,10 +347,10 @@ public class DefaultActionValidatorManag
 
     /**
-     * An {@link com.opensymphony.xwork2.validator.ValidatorContext} wrapper that
+     * An {@link org.apache.struts2.xwork2.validator.ValidatorContext} wrapper that
      * returns the full field name
      * {@link InternalValidatorContextWrapper#getFullFieldName(String)}
@@ -347,10 +347,10 @@ public class DefaultActionValidatorManag
      * returns the full field name
      * {@link InternalValidatorContextWrapper#getFullFieldName(String)}
-     * by consulting it's parent if its an {@link com.opensymphony.xwork2.validator.validators.VisitorFieldValidator.AppendingValidatorContext}.
+     * by consulting it's parent if its an {@link org.apache.struts2.xwork2.validator.validators.VisitorFieldValidator.AppendingValidatorContext}.
      * <p/>
      * Eg. if we have nested Visitor

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultValidatorFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/DefaultValidatorFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidationInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/ValidationInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,24 +13,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.validator;
+package org.apache.struts2.xwork2.validator;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.Validateable;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.DefaultWorkflowInterceptor;
-import com.opensymphony.xwork2.interceptor.MethodFilterInterceptor;
-import com.opensymphony.xwork2.interceptor.PrefixMethodInvocationUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.Validateable;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.MethodFilterInterceptor;
+import org.apache.struts2.xwork2.interceptor.PrefixMethodInvocationUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->
  *
  * This interceptor runs the action through the standard validation framework, which in turn checks the action against
  * any validation rules (found in files such as <i>ActionClass-validation.xml</i>) and adds field-level and action-level
  * error messages (provided that the action implements {@link com.opensymphony.xwork2.ValidationAware}). This interceptor
  * is often one of the last (or second to last) interceptors applied in a stack, as it assumes that all values have
  * already been set on the action.
  *
@@ -123,7 +122,7 @@ import com.opensymphony.xwork2.util.logg
  * @author Rainer Hermanns
  * @author <a href='mailto:the_mindstorm[at]evolva[dot]ro'>Alexandru Popescu</a>
  * @see ActionValidatorManager
- * @see com.opensymphony.xwork2.interceptor.DefaultWorkflowInterceptor
+ * @see org.apache.struts2.xwork2.interceptor.DefaultWorkflowInterceptor
  */
 public class ValidationInterceptor extends MethodFilterInterceptor {
 
@@ -13,24 +13,23 @@
  * This interceptor runs the action through the standard validation framework, which in turn checks the action against
  * any validation rules (found in files such as <i>ActionClass-validation.xml</i>) and adds field-level and action-level
- * error messages (provided that the action implements {@link com.opensymphony.xwork2.ValidationAware}). This interceptor
+ * error messages (provided that the action implements {@link org.apache.struts2.xwork2.ValidationAware}). This interceptor
  * is often one of the last (or second to last) interceptors applied in a stack, as it assumes that all values have
  * already been set on the action.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/Validator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/validator/Validator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================